Changelog
=========

1.0.0-alpha.2 (2016-04-04)
--------------------------

- Fix make bootstrap by:
    - adding resolutions to bower.json.
    - Use http://semver.org/ for versioning.
  [pcdummy]

1.0a1 (2016-02-14)
------------------

- Initial release.
  [pcdummy]